Function schemadb::schema::fuzzing::assert_no_panic_decoding [−][src]
pub fn assert_no_panic_decoding<S: Schema>(bytes: &[u8])Expand description
Helper used in tests and fuzzers to make sure a schema never panics when decoding random bytes.